package de.devbliss.paulparser;

/**
 * Simple Enum providing mappings for:
 * - description / keywords
 * - Citation tags (Highwire)
 * - DC Tags
 * - Prism Tags
 */
public enum MetaTags {
	////////////////////////////////////////////////////////////////////////
	// general meta tags often used by scientific publishers:
	////////////////////////////////////////////////////////////////////////
	KEYWORDS("keywords"), 	
	DESCRIPTION("description"), 

	////////////////////////////////////////////////////////////////////////
	// citation
	////////////////////////////////////////////////////////////////////////
	CITATION_ABSTRACT_HTML_URL("citation_abstract_html_url"),
	CITATION_AUTHOR("citation_author"), 
	CITATION_AUTHORS("citation_authors"), 
	CITATION_COLLECTION_ID("citation_collection_id"),
	CITATION_CONFERENCE_TITLE("citation_conference_title"), 
	CITATION_DATE("citation_date"),
	CITATION_DISSERTATION_INSTITUTION("citation_dissertation_institution"),
	CITATION_DOI("citation_doi"),
	CITATION_FIRSTPAGE("citation_firstpage"),  
	CITATION_FULLTEXT_HTML_URL("citation_fulltext_html_url"),
    CITATION_ID("citation_id"),
    CITATION_ISSUE("citation_issue"),  
    CITATION_ISSN("citation_issn"), 
    CITATION_ISBN("citation_isbn"), 
    CITATION_JOURNAL_TITLE("citation_journal_title"), 
    CITATION_JOURNAL_ABBREV("citation_journal_abbrev"),
    CITATION_KEYWORDS("citation_keywords"), 
    CITATION_LASTPAGE("citation_lastpage"),     
    CITATION_LANGUAGE("citation_language"), 
    CITATION_ONLINE_DATE("citation_online_date"), 
    CITATION_PUBLIC_URL("citation_public_url"),
    CITATION_PUBLICATION_DATE("citation_publication_date"), 
    CITATION_PUBLISHER("citation_publisher"),
    CITATION_PDF_URL("citation_pdf_url"),
    CITATION_PMID("citation_pmid"),    
    CITATION_MJID("citation_mjid"),
    CITATION_SECTION("citation_section"),
    CITATION_TECHNICAL_REPORT_INSTITUTION("citation_technical_report_institution"), 
    CITATION_TECHNICAL_REPORT_NUMBER("citation_technical_report_number"), 
	CITATION_TITLE("citation_title"), 
    CITATION_VOLUME("citation_volume"),   

	////////////////////////////////////////////////////////////////////////
	// Dublin core.
	////////////////////////////////////////////////////////////////////////
    DC_CONTRIBUTOR("DC.contributor"), 
    DC_COVERAGE("DC.coverage"), 
    DC_CREATOR("DC.creator"), 
    DC_DATE("DC.date"), 
    DC_DESCRIPTION("DC.description"), 
    DC_FORMAT("DC.format"), 
    DC_ISSUED("DC.issued"), 
    DC_IDENTIFIER("DC.identifier"), 
    DC_LANGUAGE("DC.language"), 
    DC_TITLE("DC.title"), 
    DC_RELATION("DC.relation"),    
    DC_RIGHTS("DC.rights"),
	DC_RIGHTS_AGENT("DC.rightsAgent"),
	DC_SOURCE("DC.source"), 
    DC_SUBJECT("DC.subject"), 
    DC_PUBLISHER("DC.publisher"),  
    DC_TYPE("DC.type"), 

	////////////////////////////////////////////////////////////////////////
	// Prism tags.
	////////////////////////////////////////////////////////////////////////
	PRISM_COPYRIGHT("prism.copyright"),
	PRISM_RIGHTS_AGENT("prism.rightsAgent"),
	PRISM_PUBLICATION_DATE("prism.publicationDate"),
	PRISM_VOLUME("prism.volume"),
	PRISM_ISSUE("prism.issue"),
	PRISM_NUMBER("prism.number"),
	PRISM_SECTION("prism.section"),
	PRISM_STARTING_PAGE("prism.startingPage"),
	PRISM_ENDING_PAGE("prism.endingPage"),
	PRISM_PUBLICATION_NAME("prism.publicationName"),
	PRISM_ISSN("prism.issn"),
	PRISM_E_ISSN("prism.eIssn");

	private final String tagName;

	MetaTags(String tagName) {
		this.tagName = tagName;
	}

	public String getTagName() {
		return tagName;
	}
}